import {
  select,
  json,
  tree,
  hierarchy,
  linkVertical,
  zoom,
  event
} from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top: 0, right: 50, bottom: 0, left: 75};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const nw=100;
const nh=100;
const treeLayout = tree() 
.nodeSize([nw,nh])
.separation(function(a, b) { return (a.parent == b.parent ? 1 : 2)  })
.size([innerHeight, innerWidth])
									;

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');

const g = zoomG.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));

json('data.json')
  .then(data => {
  
  const root = hierarchy(data);
   root.x0 = height / 2;
   root.y0 = 0;
    console.log(root);
  
    console.log(root);
    const links = treeLayout(root).links();
    const linkPathGenerator = linkVertical()  
      .x(d => d.x)
      .y(d => d.y);
   
      
   
     g.selectAll('g.rects')
    .data(root.descendants())
    .enter()
    .append('rect')
    .classed("rects", true)
    .attr('x', function(d) {return d.x - (nw/2);})
    .attr('y', function(d) {return d.y - (nh/2);})
    .attr('width', nw)
    .attr('height', nh)
    .attr("fill", "pink")
    .attr('stroke', "darkgray")
    .attr('stroke-width', 1);

   g.selectAll('g.nodes')
  .data(root.descendants())
  .enter()
  .append('circle') 
  .classed('node', true)
  .attr('cx', function(d) {return d.x;})
  .attr('cy', function(d) {return d.y-(nh/2);})
  .attr('r', 10)
  .attr("fill", "lightblue")
  .attr('stroke', "darkgray")
  .attr('stroke-width', 1);
  
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', (d)=>{
       
        return linkPathGenerator(getNewSourceAndTarget(d));
    });

  
  });

    function getNewSourceAndTarget({source,target}){
    return {source: {x: source.x, y: source.y+(nh/2)}, target: {x: target.x, y: target.y-(nh/2)}};
    }